@@ -11,34 +11,25 @@ from .utils import rgetattr, rsetattr
 
 
 class Deployment:
-    def __init__(self, paths=[], verbose=False):
+    def __init__(self, path="", verbose=False):
         # Initialize paths and log settings
-        self.paths = paths
+        self.path = path
         self.verbose = verbose
 
-        # Load the config and docker images
-        for path in self.paths:
-            try:
-                with open(normpath(path)) as config:
-                    self.config = yaml.safe_load(config)
-                    self.clients = {
-                        "os": os,
-                        "s3": boto3.client("s3"),
-                        "ecr": boto3.client("ecr"),
-                        "sts": boto3.client("sts"),
-                        "iam": boto3.client("iam"),
-                        "events": boto3.client("events"),
-                        "lambda": boto3.client("lambda"),
-                        "session": boto3.session.Session(),
-                        "docker": docker.client.from_env(),
-                    }
-
-                break  # success
-            except Exception as _:
-                pass
-
-        if not self.config:
-            raise "Could not resolve of awyes.yml config"
+        # Load the clients and config
+        with open(normpath(path)) as config:
+            self.config = yaml.safe_load(config)
+            self.clients = {
+                "os": os,
+                "s3": boto3.client("s3"),
+                "ecr": boto3.client("ecr"),
+                "sts": boto3.client("sts"),
+                "iam": boto3.client("iam"),
+                "events": boto3.client("events"),
+                "lambda": boto3.client("lambda"),
+                "session": boto3.session.Session(),
+                "docker": docker.client.from_env(),
+            }
 
     def get_fully_qualified_node_names(self):
         return [f"{resource_name}.{action_name}"
@@ -93,18 +84,18 @@ class Deployment:
 
     def deploy(self):
         for node in self.get_topologically_sorted_nodes():
-            name = getattr(node, "name")
-            args = getattr(node, "args")
-            client = getattr(node, "client")
+            node_name = rgetattr(node, "name")
+            node_args = rgetattr(node, "args")
+            node_client = rgetattr(self.clients, rgetattr(node, "client"))
 
-            resource_name, action_name = name.split(".")
+            resource_name, action_name = node_name.split(".")
 
             try:
-                action = getattr(client, action_name)
-                value = action(**self.shared_lookup(args))
+                action = rgetattr(node_client, action_name)
+                value = action(**self.shared_lookup(node_args))
 
                 if self.verbose:
-                    print(f"setting value {value} for {name}")
+                    print(f"setting value {value} for {node_name}")
 
                 rsetattr(
                     context=self.config,
@@ -117,7 +108,7 @@ class Deployment:
 
 def main():
     _, *path = argv
-    path = path[0] if path else ["./awyes.yml", "./awyes.yaml", "./awyes"]
+    path = path[0] if path else "./awyes.yml"
 
     Deployment(path=path).deploy()
 
